DataLad |---| data management and publication multitool
*******************************************************

Welcome to DataLad's **technical documentation**. Information here is targeting
software developers and is focused on the Python API and :term:`CLI`, as well
as software design, employed technologies, and key features.  Comprehensive
**user documentation** with information on installation, basic operation,
support, and (advanced) use case descriptions is available in the `DataLad
handbook <http://handbook.datalad.org>`_.

Content
^^^^^^^

.. toctree::
   :maxdepth: 1

   changelog
   acknowledgements
   publications

Concepts and technologies
=========================

.. toctree::
   :maxdepth: 2

   background
   related
   basics
   metadata
   customization
   design/index
   glossary

Commands and API
================

.. toctree::
   :maxdepth: 2

   cmdline
   modref
   config

Extension packages
==================

DataLad can be customized and additional functionality can be integrated via
extensions.  Each extension provides its own documentation:

- `Crawling web resources and automated data distributions <http://docs.datalad.org/projects/crawler>`_
- `Neuroimaging data and workflows <http://docs.datalad.org/projects/neuroimaging>`_
- `Containerized computational environments <http://docs.datalad.org/projects/container>`_
- `Advanced metadata tooling with JSON-LD reporting and additional metadata extractors <http://docs.datalad.org/projects/metalad>`_
- `Resources for working with the UKBiobank as a DataLad dataset <http://docs.datalad.org/projects/ukbiobank>`_
- `Deposit and retrieve DataLad datasets via the Open Science Framework <http://docs.datalad.org/projects/osf>`_
- `Functionality that has been phased out of the core package <http://docs.datalad.org/projects/deprecated>`_
- `Special interest functionality or drafts of future additions to DataLad proper <http://docs.datalad.org/projects/mihextras>`_

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
